@@ -40,10 +40,10 @@ function _aws_cdk_aws_sns_subscriptions_SubscriptionProps(p) {
 }
 function _aws_cdk_aws_sns_subscriptions_EmailSubscription(p) {
 }
-function _aws_cdk_aws_sns_subscriptions_SmsSubscription(p) {
-}
 function _aws_cdk_aws_sns_subscriptions_UrlSubscription(p) {
 }
+function _aws_cdk_aws_sns_subscriptions_SmsSubscription(p) {
+}
 function _aws_cdk_aws_sns_subscriptions_LambdaSubscription(p) {
 }
 function _aws_cdk_aws_sns_subscriptions_SqsSubscription(p) {
@@ -71,5 +71,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_sns_subscriptions_EmailSubscriptionProps, _aws_cdk_aws_sns_subscriptions_LambdaSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SqsSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SmsSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SubscriptionProps, _aws_cdk_aws_sns_subscriptions_EmailSubscription, _aws_cdk_aws_sns_subscriptions_SmsSubscription, _aws_cdk_aws_sns_subscriptions_UrlSubscription, _aws_cdk_aws_sns_subscriptions_LambdaSubscription, _aws_cdk_aws_sns_subscriptions_SqsSubscription, _aws_cdk_aws_sns_subscriptions_UrlSubscriptionProps };
+module.exports = { print, _aws_cdk_aws_sns_subscriptions_EmailSubscriptionProps, _aws_cdk_aws_sns_subscriptions_LambdaSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SqsSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SmsSubscriptionProps, _aws_cdk_aws_sns_subscriptions_SubscriptionProps, _aws_cdk_aws_sns_subscriptions_EmailSubscription, _aws_cdk_aws_sns_subscriptions_UrlSubscription, _aws_cdk_aws_sns_subscriptions_SmsSubscription, _aws_cdk_aws_sns_subscriptions_LambdaSubscription, _aws_cdk_aws_sns_subscriptions_SqsSubscription, _aws_cdk_aws_sns_subscriptions_UrlSubscriptionProps };
 module.exports.DeprecationError = DeprecationError;
